..
      Copyright 2011-2012 OpenStack Foundation
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

================
Getting Involved
================

The OpenStack community is a very friendly group and there are places online to
join in with the community. Feel free to ask questions. This document points
you to some of the places where you can communicate with people.

How to Join the Community
=========================

Our community welcomes all people interested in open source cloud computing,
and there are no formal membership requirements. The best way to join the
community is to talk with others online or at a meetup and offer contributions
through Launchpad_, the wiki_, or blogs. We welcome all types of contributions,
from blueprint designs to documentation to testing to deployment scripts.

.. _Launchpad: https://launchpad.net/keystone
.. _wiki: https://wiki.openstack.org/

#openstack-keystone on Freenode IRC Network
-------------------------------------------

You can find Keystone folks in `<irc://freenode.net/#openstack-keystone>`_.
This is usually the best place to ask questions and find your way around. IRC
stands for Internet Relay Chat and it is a way to chat online in real time.
You can also ask a question and come back to the log files to read the answer
later. Logs for the #openstack IRC channels are stored at
`<http://eavesdrop.openstack.org/irclogs/>`_.

For more information regarding OpenStack IRC channels please visit the
`OpenStack IRC Wiki <https://wiki.openstack.org/wiki/IRC>`_.

OpenStack Wiki
--------------

The wiki is a living source of knowledge. It is edited by the community, and
has collections of links and other sources of information. Typically the pages
are a good place to write drafts for specs or documentation, describe a
blueprint, or collaborate with others.

`OpenStack Wiki <https://wiki.openstack.org/>`_

* `useful Keystone project links <https://wiki.openstack.org/Keystone>`_

Keystone on Launchpad
---------------------

Launchpad is a code hosting that OpenStack is using to track bugs, feature
work, and releases of OpenStack. Like other OpenStack projects, Keystone source
code is hosted on opendev.org

* `Keystone Project Page on Launchpad <https://launchpad.net/keystone>`_
* `Keystone Source Repository <https://opendev.org/openstack/keystone>`_

Within launchpad, we use
`blueprints <https://blueprints.launchpad.net/keystone>`_, to track feature
work, and track `bugs <https://bugs.launchpad.net/keystone>`_ as well. If
you are looking for a place to get started contributing to keystone, please
look at any bugs for Keystone that are tagged as `low-hanging-fruit
<https://bugs.launchpad.net/keystone/+bugs?field.tag=low-hanging-fruit>`_.

OpenStack Blog
--------------

The OpenStack blog includes a weekly newsletter that aggregates OpenStack news
from around the internet, as well as providing inside information on upcoming
events and posts from OpenStack contributors.

`OpenStack Blog <https://openstack.org/blog>`_

See also: `Planet OpenStack <http://planet.openstack.org/>`_, an aggregation of
blogs about OpenStack from around the internet, combined into a web site and
RSS feed. If you'd like to contribute with your blog posts, there are
instructions for `adding your blog <https://wiki.openstack.org/AddingYourBlog>`_.


Twitter
-------

Because all the cool kids do it: `@openstack <http://twitter.com/openstack>`_.
Also follow the `#openstack <https://twitter.com/search?q=%23openstack>`_
tag for relevant tweets.
